ProSHADE: Class List

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

Class List
Here are the classes, structs, unions and interfaces with brief descriptions:
[detail level 12]

▼N ProSHADE_internal_data | This namespace contains the structure and functions required for data reading and storing their derivates
C ProSHADE_data | This class contains all inputed and derived data for a single structure
▼N ProSHADE_internal_maths | This namespace contains the internal functions for common mathematical operations
C BicubicInterpolator |
▼N ProSHADE_internal_spheres | This namespace contains the structure and functions required for storing internal map projections onto a set of concentric spheres
C ProSHADE_rotFun_sphere | This class contains all inputed data for the rotation function angle-axis converted spheres
C ProSHADE_rotFun_spherePeakGroup | This class contains peak groups detected in the rotation function mapped spheres
C ProSHADE_sphere | This class contains all inputed and derived data for a single sphere
C ProSHADE_exception | This class is the representation of ProSHADE exception
C ProSHADE_internal_maths_bicubicInterpolator | This class takes 4 by 4 array of input point values and allows bicubic interpolation of any value between them
C ProSHADE_run | This class provides the access point to the library
C ProSHADE_settings | This class stores all the settings and is passed to the executive classes instead of a multitude of parameters